@@ -33,43 +33,43 @@
 */
 /*
  * jcobyla
- * 
+ *
  * The MIT License
  *
  * Copyright (c) 2012 Anders Gustafsson, Cureos AB.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files
- * (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, 
- * publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, 
+ * (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge,
+ * publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
  * subject to the following conditions:
  *
  * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
  *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
- * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE 
- * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
+ * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
- * 
+ *
  * Remarks:
- * 
+ *
  * The original Fortran 77 version of this code was by Michael Powell (M.J.D.Powell @ damtp.cam.ac.uk)
  * The Fortran 90 version was by Alan Miller (Alan.Miller @ vic.cmis.csiro.au). Latest revision - 30 October 1998
  */
 
 /**
  * Constrained Optimization BY Linear Approximation in Java.
- * 
+ *
  * COBYLA2 is an implementation of Powell's nonlinear derivative free constrained optimization that uses
  * a linear approximation approach. The algorithm is a sequential trust region algorithm that employs linear
  * approximations to the objective and constraint functions, where the approximations are formed by linear
  * interpolation at n + 1 points in the space of the variables and tries to maintain a regular shaped simplex
  * over iterations.
- * 
+ *
  * It solves nonsmooth NLP with a moderate number of variables (about 100). Inequality constraints only.
- * 
+ *
  * The initial point X is taken as one vertex of the initial simplex with zero being another, so, X should
  * not be entered as the zero vector.
- * 
+ *
  * @author Anders Gustafsson, Cureos AB. Translation to Javascript by Reinhard Oldenburg, Goethe-University
  */
 
@@ -82,7 +82,7 @@
  utils/type
  */
 
-define(['jxg'], function (JXG) {
+define(['jxg', 'utils/type'], function (JXG, Type) {
 
     "use strict";
 
@@ -90,20 +90,29 @@ define(['jxg'], function (JXG) {
      * The JXG.Math.Nlp namespace holds numerical algorithms for non-linear optimization.
      * @name JXG.Math.Nlp
      * @namespace
-     * 
+     *
      */
-    JXG.Math.Nlp =  {
+    JXG.Math.Nlp = {
 
-        arr: function(n) {
-            var a = new Array(n),
-                i;
-            for (i = 0; i <n ; i++) {
-                a[i] = 0.0;
-            }
-            return a;
+        arr: function (n) {
+            // Is 0 initialized
+            return new Float64Array(n);
+
+            // var a = new Array(n),
+            //     i;
+
+            // if (Type.exists(a.fill)) {
+            //     a.fill(0.0, 0, n);
+            // } else {
+            //     for (i = 0; i < n; i++) {
+            //         a[i] = 0.0;
+            //     }
+            // }
+
+            // return a;
         },
 
-        arr2: function(n, m) {
+        arr2: function (n, m) {
             var i = 0,
                 a = new Array(n);
 
@@ -114,7 +123,7 @@ define(['jxg'], function (JXG) {
             return a;
         },
 
-        arraycopy: function(x, a, iox, b, n) {
+        arraycopy: function (x, a, iox, b, n) {
             var i = 0;
             while (i < n) {
                 iox[i + b] = x[i + a];
@@ -144,7 +153,7 @@ define(['jxg'], function (JXG) {
          * @param maxfun Maximum number of function evaluations before terminating.
          * @returns {Number} Exit status of the COBYLA2 optimization.
          */
-        FindMinimum: function(calcfc, n,  m, x, rhobeg, rhoend,  iprint,  maxfun) {
+        FindMinimum: function (calcfc, n, m, x, rhobeg, rhoend, iprint, maxfun) {
             // CobylaExitStatus FindMinimum(final Calcfc calcfc, int n, int m, double[] x, double rhobeg, double rhoend, int iprint, int maxfun)
             //     This subroutine minimizes an objective function F(X) subject to M
             //     inequality constraints on X, where X is a vector of variables that has
@@ -208,16 +217,16 @@ define(['jxg'], function (JXG) {
 
             // Internal representation of the objective and constraints calculation method,
             // accounting for that X and CON arrays in the cobylb method are base-1 arrays.
-            fcalcfc = function(n, m, thisx, con) {  // int n, int m, double[] x, double[] con
-                    var ix = that.arr(n),
-                        ocon, f;
+            fcalcfc = function (n, m, thisx, con) {  // int n, int m, double[] x, double[] con
+                var ix = that.arr(n),
+                    ocon, f;
 
-                    that.arraycopy(thisx, 1, ix, 0, n);
-                    ocon = that.arr(m);
-                    f = calcfc(n, m, ix, ocon);
-                    that.arraycopy(ocon, 0, con, 1, m);
-                    return f;
-                };
+                that.arraycopy(thisx, 1, ix, 0, n);
+                ocon = that.arr(m);
+                f = calcfc(n, m, ix, ocon);
+                that.arraycopy(ocon, 0, con, 1, m);
+                return f;
+            };
 
             status = this.cobylb(fcalcfc, n, m, mpp, iox, rhobeg, rhoend, iprint, maxfun);
             this.arraycopy(iox, 1, x, 0, n);
@@ -229,18 +238,18 @@ define(['jxg'], function (JXG) {
         //      double rhobeg, double rhoend, int iprint, int maxfun)
         /**
          * JavaScript implementation of the non-linear optimization method COBYLA.
-         * @param {Function} calcfc 
-         * @param {Number} n 
-         * @param {Number} m 
-         * @param {Number} mpp 
-         * @param {Number} x 
-         * @param {Number} rhobeg 
-         * @param {Number} rhoend 
-         * @param {Number} iprint 
-         * @param {Number} maxfun 
+         * @param {Function} calcfc
+         * @param {Number} n
+         * @param {Number} m
+         * @param {Number} mpp
+         * @param {Number} x
+         * @param {Number} rhobeg
+         * @param {Number} rhoend
+         * @param {Number} iprint
+         * @param {Number} maxfun
          * @returns {Number} Exit status of the COBYLA2 optimization
          */
-        cobylb: function (calcfc, n,  m,  mpp,  x, rhobeg,  rhoend,  iprint,  maxfun) {
+        cobylb: function (calcfc, n, m, mpp, x, rhobeg, rhoend, iprint, maxfun) {
             // calcf ist funktion die aufgerufen wird wie calcfc(n, m, ix, ocon)
             // N.B. Arguments CON, SIM, SIMI, DATMAT, A, VSIG, VETA, SIGBAR, DX, W & IACT
             //      have been removed.
@@ -416,8 +425,7 @@ define(['jxg'], function (JXG) {
                                     sim[i][np] += temp;
 
                                     tempa = 0.0;
-                                    for (k = 1; k <= n; ++k)
-                                    {
+                                    for (k = 1; k <= n; ++k) {
                                         sim[i][k] -= temp;
                                         tempa -= simi[k][i];
                                     }
@@ -428,13 +436,17 @@ define(['jxg'], function (JXG) {
                             //     Make an error return if SIGI is a poor approximation to the inverse of
                             //     the leading N by N submatrix of SIG.
                             error = 0.0;
-                            for (i = 1; i <= n; ++i) {
-                                for (j = 1; j <= n; ++j) {
-                                    temp = this.DOT_PRODUCT(
-                                            this.PART(this.ROW(simi, i), 1, n),
-                                            this.PART(this.COL(sim, j), 1, n)
-                                        ) - (i === j ? 1.0 : 0.0);
-                                    error = Math.max(error, Math.abs(temp));
+                            if (false) {
+                                for (i = 1; i <= n; ++i) {
+                                    for (j = 1; j <= n; ++j) {
+                                        temp = this.DOT_PRODUCT_ROW_COL(simi, i, sim, j, 1, n) - (i === j ? 1.0 : 0.0);
+                                        // temp = this.DOT_PRODUCT(
+                                        //     this.PART(this.ROW(simi, i), 1, n),
+                                        //     this.PART(this.COL(sim, j), 1, n)
+                                        // ) - (i === j ? 1.0 : 0.0);
+
+                                        error = Math.max(error, Math.abs(temp));
+                                    }
                                 }
                             }
                             if (error > 0.1) {
@@ -453,8 +465,9 @@ define(['jxg'], function (JXG) {
                                 }
 
                                 for (i = 1; i <= n; ++i) {
-                                    a[i][k] = (k === mp ? -1.0 : 1.0) * this.DOT_PRODUCT(
-                                        this.PART(w, 1, n), this.PART(this.COL(simi, i), 1, n));
+                                    a[i][k] = (k === mp ? -1.0 : 1.0) *
+                                        this.DOT_PRODUCT_ROW_COL(w, -1, simi, i, 1, n);
+                                    // this.DOT_PRODUCT(this.PART(w, 1, n), this.PART(this.COL(simi, i), 1, n));
                                 }
                             }
 
@@ -466,11 +479,9 @@ define(['jxg'], function (JXG) {
 
                             for (j = 1; j <= n; ++j) {
                                 wsig = 0.0;
-                                for (k = 1; k <= n; ++k) {
-                                    wsig += simi[j][k] * simi[j][k];
-                                }
                                 weta = 0.0;
                                 for (k = 1; k <= n; ++k) {
+                                    wsig += simi[j][k] * simi[j][k];
                                     weta += sim[k][j] * sim[k][j];
                                 }
                                 vsig[j] = 1.0 / Math.sqrt(wsig);
@@ -507,10 +518,8 @@ define(['jxg'], function (JXG) {
                                 cvmaxm = 0.0;
                                 total = 0.0;
                                 for (k = 1; k <= mp; ++k) {
-                                    total = this.DOT_PRODUCT(
-                                        this.PART(this.COL(a, k), 1, n),
-                                        this.PART(dx, 1, n)
-                                        );
+                                    // total = this.DOT_PRODUCT(this.PART(this.COL(a, k), 1, n), this.PART(dx, 1, n));
+                                    total = this.DOT_PRODUCT_ROW_COL(dx, -1, a, k, 1, n);
                                     if (k < mp) {
                                         temp = datmat[k][np];
                                         cvmaxp = Math.max(cvmaxp, -total - temp);
@@ -532,10 +541,8 @@ define(['jxg'], function (JXG) {
 
                                 for (j = 1; j <= n; ++j) {
                                     if (j !== jdrop) {
-                                        temp = this.DOT_PRODUCT(
-                                            this.PART(this.ROW(simi, j), 1, n),
-                                            this.PART(dx, 1, n)
-                                            );
+                                        // temp = this.DOT_PRODUCT(this.PART(this.ROW(simi, j), 1, n), this.PART(dx, 1, n));
+                                        temp = this.DOT_PRODUCT_ROW_COL(simi, j, dx, -1, 1, n);
                                         for (k = 1; k <= n; ++k) {
                                             simi[j][k] -= temp * simi[jdrop][k];
                                         }
@@ -565,7 +572,8 @@ define(['jxg'], function (JXG) {
                             resnew = 0.0;
                             con[mp] = 0.0;
                             for (k = 1; k <= mp; ++k) {
-                                total = con[k] - this.DOT_PRODUCT(this.PART(this.COL(a, k), 1, n), this.PART(dx, 1, n));
+                                //total = con[k] - this.DOT_PRODUCT(this.PART(this.COL(a, k), 1, n), this.PART(dx, 1, n));
+                                total = con[k] - this.DOT_PRODUCT_ROW_COL(dx, -1, a, k, 1, n);
                                 if (k < mp) { resnew = Math.max(resnew, total); }
                             }
 
@@ -613,7 +621,8 @@ define(['jxg'], function (JXG) {
                         ratio = trured <= 0.0 ? 1.0 : 0.0;
                         jdrop = 0;
                         for (j = 1; j <= n; ++j) {
-                            temp = Math.abs(this.DOT_PRODUCT(this.PART(this.ROW(simi, j), 1, n), this.PART(dx, 1, n)));
+                            // temp = Math.abs(this.DOT_PRODUCT(this.PART(this.ROW(simi, j), 1, n), this.PART(dx, 1, n)));
+                            temp = Math.abs(this.DOT_PRODUCT_ROW_COL(simi, j, dx, -1, 1, n));
                             if (temp > ratio) {
                                 jdrop = j;
                                 ratio = temp;
@@ -653,7 +662,8 @@ define(['jxg'], function (JXG) {
                             for (k = 1; k <= n; ++k) { simi[jdrop][k] /= temp; }
                             for (j = 1; j <= n; ++j) {
                                 if (j !== jdrop) {
-                                    temp = this.DOT_PRODUCT(this.PART(this.ROW(simi, j), 1, n), this.PART(dx, 1, n));
+                                    // temp = this.DOT_PRODUCT(this.PART(this.ROW(simi, j), 1, n), this.PART(dx, 1, n));
+                                    temp = this.DOT_PRODUCT_ROW_COL(simi, j, dx, -1, 1, n);
                                     for (k = 1; k <= n; ++k) {
                                         simi[j][k] -= temp * simi[jdrop][k];
                                     }
@@ -706,7 +716,7 @@ define(['jxg'], function (JXG) {
                         }
                     }
                     if (iprint >= 2) {
-                        console.log("Reduction in RHO to "+rho+"  and PARMU = "+parmu);
+                        console.log("Reduction in RHO to " + rho + "  and PARMU = " + parmu);
                     }
                     if (iprint === 2) {
                         this.PrintIterationResult(nfvals, datmat[mp][np], datmat[mpp][np], this.COL(sim, np), n, iprint);
@@ -742,7 +752,7 @@ define(['jxg'], function (JXG) {
             return status;
         },
 
-        trstlp: function(n,  m,  a, b, rho,  dx) { //(int n, int m, double[][] a, double[] b, double rho, double[] dx)
+        trstlp: function (n, m, a, b, rho, dx) { //(int n, int m, double[][] a, double[] b, double rho, double[] dx)
             // N.B. Arguments Z, ZDOTA, VMULTC, SDIRN, DXNEW, VMULTD & IACT have been removed.
 
             //     This subroutine calculates an N-component vector DX by applying the
@@ -856,9 +866,8 @@ define(['jxg'], function (JXG) {
 
                     L_70:
                     do {
-                        optnew = (mcon === m) ? resmax : -this.DOT_PRODUCT(
-                                this.PART(dx, 1, n), this.PART(this.COL(a, mcon), 1, n)
-                            );
+                        // optnew = (mcon === m) ? resmax : -this.DOT_PRODUCT(this.PART(dx, 1, n), this.PART(this.COL(a, mcon), 1, n));
+                        optnew = (mcon === m) ? resmax : -this.DOT_PRODUCT_ROW_COL(dx, -1, a, mcon, 1, n);
 
                         if (icount === 0 || optnew < optold) {
                             optold = optnew;
@@ -889,9 +898,9 @@ define(['jxg'], function (JXG) {
                                     kp = k + 1;
                                     kk = iact[kp];
                                     sp = this.DOT_PRODUCT(
-                                            this.PART(this.COL(z, k), 1, n),
-                                            this.PART(this.COL(a, kk), 1, n)
-                                        );
+                                        this.PART(this.COL(z, k), 1, n),
+                                        this.PART(this.COL(a, kk), 1, n)
+                                    );
                                     temp = Math.sqrt(sp * sp + zdota[kp] * zdota[kp]);
                                     alpha = zdota[kp] / temp;
                                     beta = sp / temp;
@@ -919,9 +928,8 @@ define(['jxg'], function (JXG) {
                                 temp = 1.0 / zdota[nact];
                                 for (k = 1; k <= n; ++k) { sdirn[k] = temp * z[k][nact]; }
                             } else {
-                                temp = this.DOT_PRODUCT(
-                                        this.PART(sdirn, 1, n), this.PART(this.COL(z, nact + 1), 1, n)
-                                    );
+                                // temp = this.DOT_PRODUCT(this.PART(sdirn, 1, n), this.PART(this.COL(z, nact + 1), 1, n));
+                                temp = this.DOT_PRODUCT_ROW_COL(sdirn, -1, z, nact + 1, 1, n);
                                 for (k = 1; k <= n; ++k) { sdirn[k] -= temp * z[k][nact + 1]; }
                             }
                         } else {
@@ -930,34 +938,34 @@ define(['jxg'], function (JXG) {
                             tot = 0.0;
 
                             // {
-                                k = n;
-                                while (k > nact) {
-                                    sp = 0.0;
-                                    spabs = 0.0;
-                                    for (i = 1; i <= n; ++i) {
-                                        temp = z[i][k] * dxnew[i];
-                                        sp += temp;
-                                        spabs += Math.abs(temp);
-                                    }
-                                    acca = spabs + 0.1 * Math.abs(sp);
-                                    accb = spabs + 0.2 * Math.abs(sp);
-                                    if (spabs >= acca || acca >= accb) { sp = 0.0; }
-                                    if (tot === 0.0) {
-                                        tot = sp;
-                                    } else {
-                                        kp = k + 1;
-                                        temp = Math.sqrt(sp * sp + tot * tot);
-                                        alpha = sp / temp;
-                                        beta = tot / temp;
-                                        tot = temp;
-                                        for (i = 1; i <= n; ++i) {
-                                            temp = alpha * z[i][k] + beta * z[i][kp];
-                                            z[i][kp] = alpha * z[i][kp] - beta * z[i][k];
-                                            z[i][k] = temp;
-                                        }
-                                    }
-                                    --k;
+                            k = n;
+                            while (k > nact) {
+                                sp = 0.0;
+                                spabs = 0.0;
+                                for (i = 1; i <= n; ++i) {
+                                    temp = z[i][k] * dxnew[i];
+                                    sp += temp;
+                                    spabs += Math.abs(temp);
                                 }
+                                acca = spabs + 0.1 * Math.abs(sp);
+                                accb = spabs + 0.2 * Math.abs(sp);
+                                if (spabs >= acca || acca >= accb) { sp = 0.0; }
+                                if (tot === 0.0) {
+                                    tot = sp;
+                                } else {
+                                    kp = k + 1;
+                                    temp = Math.sqrt(sp * sp + tot * tot);
+                                    alpha = sp / temp;
+                                    beta = tot / temp;
+                                    tot = temp;
+                                    for (i = 1; i <= n; ++i) {
+                                        temp = alpha * z[i][k] + beta * z[i][kp];
+                                        z[i][kp] = alpha * z[i][kp] - beta * z[i][k];
+                                        z[i][k] = temp;
+                                    }
+                                }
+                                --k;
+                            }
                             // }
 
                             if (tot === 0.0) {
@@ -970,34 +978,34 @@ define(['jxg'], function (JXG) {
 
                                 ratio = -1.0;
                                 //{
-                                    k = nact;
-                                    do {
-                                        zdotv = 0.0;
-                                        zdvabs = 0.0;
+                                k = nact;
+                                do {
+                                    zdotv = 0.0;
+                                    zdvabs = 0.0;
 
-                                        for (i = 1; i <= n; ++i) {
-                                            temp = z[i][k] * dxnew[i];
-                                            zdotv += temp;
-                                            zdvabs += Math.abs(temp);
+                                    for (i = 1; i <= n; ++i) {
+                                        temp = z[i][k] * dxnew[i];
+                                        zdotv += temp;
+                                        zdvabs += Math.abs(temp);
+                                    }
+                                    acca = zdvabs + 0.1 * Math.abs(zdotv);
+                                    accb = zdvabs + 0.2 * Math.abs(zdotv);
+                                    if (zdvabs < acca && acca < accb) {
+                                        temp = zdotv / zdota[k];
+                                        if (temp > 0.0 && iact[k] <= m) {
+                                            tempa = vmultc[k] / temp;
+                                            if (ratio < 0.0 || tempa < ratio) { ratio = tempa; }
                                         }
-                                        acca = zdvabs + 0.1 * Math.abs(zdotv);
-                                        accb = zdvabs + 0.2 * Math.abs(zdotv);
-                                        if (zdvabs < acca && acca < accb) {
-                                            temp = zdotv / zdota[k];
-                                            if (temp > 0.0 && iact[k] <= m) {
-                                                tempa = vmultc[k] / temp;
-                                                if (ratio < 0.0 || tempa < ratio) { ratio = tempa; }
-                                            }
 
-                                            if (k >= 2) {
-                                                kw = iact[k];
-                                                for (i = 1; i <= n; ++i) { dxnew[i] -= temp * a[i][kw]; }
-                                            }
-                                            vmultd[k] = temp;
-                                        } else {
-                                            vmultd[k] = 0.0;
+                                        if (k >= 2) {
+                                            kw = iact[k];
+                                            for (i = 1; i <= n; ++i) { dxnew[i] -= temp * a[i][kw]; }
                                         }
-                                    } while (--k > 0);
+                                        vmultd[k] = temp;
+                                    } else {
+                                        vmultd[k] = 0.0;
+                                    }
+                                } while (--k > 0);
                                 //}
                                 if (ratio < 0.0) { break L_60; }
 
@@ -1016,9 +1024,9 @@ define(['jxg'], function (JXG) {
                                         kp = k + 1;
                                         kw = iact[kp];
                                         sp = this.DOT_PRODUCT(
-                                                this.PART(this.COL(z, k), 1, n),
-                                                this.PART(this.COL(a, kw), 1, n)
-                                            );
+                                            this.PART(this.COL(z, k), 1, n),
+                                            this.PART(this.COL(a, kw), 1, n)
+                                        );
                                         temp = Math.sqrt(sp * sp + zdota[kp] * zdota[kp]);
                                         alpha = zdota[kp] / temp;
                                         beta = sp / temp;
@@ -1037,9 +1045,9 @@ define(['jxg'], function (JXG) {
                                     vmultc[k] = vsave;
                                 }
                                 temp = this.DOT_PRODUCT(
-                                            this.PART(this.COL(z, nact), 1, n),
-                                            this.PART(this.COL(a, kk), 1, n)
-                                        );
+                                    this.PART(this.COL(z, nact), 1, n),
+                                    this.PART(this.COL(a, kk), 1, n)
+                                );
                                 if (temp === 0.0) { break L_60; }
                                 zdota[nact] = temp;
                                 vmultc[icon] = 0.0;
@@ -1062,9 +1070,9 @@ define(['jxg'], function (JXG) {
                             if (mcon > m && kk !== mcon) {
                                 k = nact - 1;
                                 sp = this.DOT_PRODUCT(
-                                        this.PART(this.COL(z, k), 1, n),
-                                        this.PART(this.COL(a, kk), 1, n)
-                                    );
+                                    this.PART(this.COL(z, k), 1, n),
+                                    this.PART(this.COL(a, kk), 1, n)
+                                );
                                 temp = Math.sqrt(sp * sp + zdota[nact] * zdota[nact]);
                                 alpha = zdota[nact] / temp;
                                 beta = sp / temp;
@@ -1090,10 +1098,8 @@ define(['jxg'], function (JXG) {
                                 for (k = 1; k <= n; ++k) { sdirn[k] = temp * z[k][nact]; }
                             } else {
                                 kk = iact[nact];
-                                temp = (this.DOT_PRODUCT(
-                                            this.PART(sdirn, 1, n),
-                                            this.PART(this.COL(a, kk), 1, n)
-                                        ) - 1.0) / zdota[nact];
+                                // temp = (this.DOT_PRODUCT(this.PART(sdirn, 1, n),this.PART(this.COL(a, kk), 1, n)) - 1.0) / zdota[nact];
+                                temp = (this.DOT_PRODUCT_ROW_COL(sdirn, -1, a, kk, 1, n) - 1.0) / zdota[nact];
                                 for (k = 1; k <= n; ++k) { sdirn[k] -= temp * z[k][nact]; }
                             }
                         }
@@ -1133,9 +1139,8 @@ define(['jxg'], function (JXG) {
                             resmax = 0.0;
                             for (k = 1; k <= nact; ++k) {
                                 kk = iact[k];
-                                temp = b[kk] - this.DOT_PRODUCT(
-                                        this.PART(this.COL(a, kk), 1, n), this.PART(dxnew, 1, n)
-                                    );
+                                // temp = b[kk] - this.DOT_PRODUCT(this.PART(this.COL(a, kk), 1, n), this.PART(dxnew, 1, n));
+                                temp = b[kk] - this.DOT_PRODUCT_ROW_COL(dxnew, -1, a, kk, 1, n);
                                 resmax = Math.max(resmax, temp);
                             }
                         }
@@ -1145,25 +1150,25 @@ define(['jxg'], function (JXG) {
                         //     can be attributed to computer rounding errors. First calculate the new
                         //     Lagrange multipliers.
                         //{
-                            k = nact;
-                            do {
-                                zdotw = 0.0;
-                                zdwabs = 0.0;
-                                for (i = 1; i <= n; ++i) {
-                                    temp = z[i][k] * dxnew[i];
-                                    zdotw += temp;
-                                    zdwabs += Math.abs(temp);
-                                }
-                                acca = zdwabs + 0.1 * Math.abs(zdotw);
-                                accb = zdwabs + 0.2 * Math.abs(zdotw);
-                                if (zdwabs >= acca || acca >= accb) { zdotw = 0.0; }
-                                vmultd[k] = zdotw / zdota[k];
-                                if (k >= 2) {
-                                    kk = iact[k];
-                                    for (i = 1; i <= n; ++i) { dxnew[i] -= vmultd[k] * a[i][kk]; }
-                                }
-                            } while (k-- >= 2);
-                            if (mcon > m) { vmultd[nact] = Math.max(0.0, vmultd[nact]); }
+                        k = nact;
+                        do {
+                            zdotw = 0.0;
+                            zdwabs = 0.0;
+                            for (i = 1; i <= n; ++i) {
+                                temp = z[i][k] * dxnew[i];
+                                zdotw += temp;
+                                zdwabs += Math.abs(temp);
+                            }
+                            acca = zdwabs + 0.1 * Math.abs(zdotw);
+                            accb = zdwabs + 0.2 * Math.abs(zdotw);
+                            if (zdwabs >= acca || acca >= accb) { zdotw = 0.0; }
+                            vmultd[k] = zdotw / zdota[k];
+                            if (k >= 2) {
+                                kk = iact[k];
+                                for (i = 1; i <= n; ++i) { dxnew[i] -= vmultd[k] * a[i][kk]; }
+                            }
+                        } while (k-- >= 2);
+                        if (mcon > m) { vmultd[nact] = Math.max(0.0, vmultd[nact]); }
                         //}
 
                         //     Complete VMULTC by finding the new constraint residuals.
@@ -1228,12 +1233,12 @@ define(['jxg'], function (JXG) {
             return false;
         },
 
-        PrintIterationResult: function(nfvals, f, resmax,  x,  n, iprint) {
-            if (iprint > 1) { console.log("NFVALS = "+nfvals+"  F = "+f+"  MAXCV = "+resmax); }
+        PrintIterationResult: function (nfvals, f, resmax, x, n, iprint) {
+            if (iprint > 1) { console.log("NFVALS = " + nfvals + "  F = " + f + "  MAXCV = " + resmax); }
             if (iprint > 1) { console.log("X = " + this.PART(x, 1, n)); }
         },
 
-        ROW: function(src, rowidx) {
+        ROW: function (src, rowidx) {
             return src[rowidx].slice();
             // var col,
             //     cols = src[0].length,
@@ -1245,17 +1250,18 @@ define(['jxg'], function (JXG) {
             // return dest;
         },
 
-        COL: function(src, colidx) {
+        COL: function (src, colidx) {
             var row,
                 rows = src.length,
-                dest = this.arr(rows);
+                dest = []; // this.arr(rows);
+
             for (row = 0; row < rows; ++row) {
                 dest[row] = src[row][colidx];
             }
             return dest;
         },
 
-        PART: function(src, from, to) {
+        PART: function (src, from, to) {
             return src.slice(from, to + 1);
             // var srcidx,
             //     dest = this.arr(to - from + 1),
@@ -1266,7 +1272,7 @@ define(['jxg'], function (JXG) {
             // return dest;
         },
 
-        FORMAT: function(x) {
+        FORMAT: function (x) {
             return x.join(',');
             // var i, fmt = "";
             // for (i = 0; i < x.length; ++i) {
@@ -1275,12 +1281,38 @@ define(['jxg'], function (JXG) {
             // return fmt;
         },
 
-        DOT_PRODUCT: function(lhs,  rhs) {
+        DOT_PRODUCT: function (lhs, rhs) {
             var i, sum = 0.0,
                 len = lhs.length;
             for (i = 0; i < len; ++i) {
                 sum += lhs[i] * rhs[i];
             }
+            return sum;
+        },
+
+        DOT_PRODUCT_ROW_COL: function (lhs, row, rhs, col, start, end) {
+            var i, sum = 0.0;
+
+            if (row === -1) {
+                // lhs is vector
+                for (i = start; i <= end; ++i) {
+                    sum += lhs[i] * rhs[i][col];
+                }
+            } else {
+                // lhs is row of matrix
+                if (col === -1) {
+                    // rhs is vector
+                    for (i = start; i <= end; ++i) {
+                        sum += lhs[row][i] * rhs[i];
+                    }
+                } else {
+                    // rhs is column of matrix
+                    for (i = start; i <= end; ++i) {
+                        sum += lhs[row][i] * rhs[i][col];
+                    }
+                }
+            }
+
             return sum;
         }
 
