@@ -74,8 +74,26 @@ describe("Test geometry functions", function() {
             [1, 1, 2], [2, -2, 4]
         );
         expect(res).toEqual([[1, -1, 2], 1.5, 1]);
+    });
 
+    it("meetPathPath", function() {
+        var pol1, pol2, p;
 
+        pol1 = board.create('polygon', [[1, 1], [2, 0], [1, 2], [-1,1]]);
+        pol2 = board.create('polygon', [[1, 1.5], [2, 2], [0, 3], [0,0.5]]);
+        p = board.create('intersection', [pol1, pol2, 3]);
+        expect([p.X(), p.Y()]).toEqual([0.5, 1]);
+    });
+
+    it("meetPolygonLine", function() {
+        var pol1, li, p;
+
+        pol1 = board.create('polygon', [[1, 1], [2, 0], [1, 2], [-1,1]]);
+        li = board.create('line', [[-2,2], [4,-2]]);
+        p = board.create('intersection', [pol1, li, 0]);
+
+        expect(p.X()).toBeCloseTo(-0.7142857142857143, 7);
+        expect(p.Y()).toBeCloseTo(1.1428571428571428, 7);
     });
 
 });
